@@ -21,7 +21,8 @@
 */
 
 #include <QDir>
-#include <QOperatingSystemVersion>
+//#include <QOperatingSystemVersion> // not present before Qt 5.9
+#include <QSysInfo>
 
 #include "qutecsound.h"
 #include "configdialog.h"
@@ -194,6 +195,8 @@ ConfigDialog::ConfigDialog(CsoundQt *parent, Options *options, ConfigLists *conf
     toolbarIconSizeSpinBox->setValue(m_options->toolbarIconSize);
 	wrapLinesCheckBox->setChecked(m_options->wrapLines);
 	autoCompleteCheckBox->setChecked(m_options->autoComplete);
+    autoCompleteDelaySpinBox->setValue(m_options->autoCompleteDelay);
+
 	autoParameterModeCheckBox->setChecked(m_options->autoParameterMode);
 	widgetsCheckBox->setChecked(m_options->enableWidgets);
 	midiCcToCurrentPageOnlyCheckBox->setChecked(m_options->midiCcToCurrentPageOnly);
@@ -422,8 +425,8 @@ void ConfigDialog::onRtModuleComboBoxChanged(int index) {
     // Todo: remember the settings for each backend in a hash table, and set it to the last
     // known value when changed back. Otherwise set it to the default adc/dac
     auto currentText = this->RtModuleComboBox->currentText();
-	auto currentOperatingSystem = QOperatingSystemVersion::current();
-    //qDebug() << "module: " << currentText << "Op.system type is: " << currentOperatingSystem.type() << currentOperatingSystem.name();
+    //auto currentOperatingSystem = QOperatingSystemVersion::current();
+    //qDebug() << "module: " << currentText << "Op.system type is: " << QSysInfo::productType() ;
     if(currentText == "null") {
         RtInputLineEdit->setText("");
         RtOutputLineEdit->setText("");
@@ -443,7 +446,7 @@ void ConfigDialog::onRtModuleComboBoxChanged(int index) {
             m_options->useSystemSamplerate = false;
             m_options->samplerate = 0;
         }
-    } else if (currentText.startsWith("portaudio") && currentOperatingSystem.type()==QOperatingSystemVersion::MacOS ) { // on newer Mac's the internal microphone has 1 channel and that causes problems for portaudio. Disable input by default
+    } else if (currentText.startsWith("portaudio") && QSysInfo::productType()=="osx" ) { // on newer Mac's the internal microphone has 1 channel and that causes problems for portaudio. Disable input by default
 			qDebug() << "Set audio input to none for portaudio on MacOS";
 			RtInputLineEdit->setText("");
 			RtOutputLineEdit->setText("dac");
@@ -501,6 +504,7 @@ void ConfigDialog::accept()
     m_options->toolbarIconSize = toolbarIconSizeSpinBox->value();
 	m_options->wrapLines = wrapLinesCheckBox->isChecked();
 	m_options->autoComplete = autoCompleteCheckBox->isChecked();
+    m_options->autoCompleteDelay = autoCompleteDelaySpinBox->value();
 	m_options->autoParameterMode = autoParameterModeCheckBox->isChecked();
 	m_options->enableWidgets = widgetsCheckBox->isChecked();
 	m_options->midiCcToCurrentPageOnly = midiCcToCurrentPageOnlyCheckBox->isChecked();
