@@ -174,20 +174,26 @@ void DockHelp::loadFile(QString fileName, QString anchor) {
         ui->text->setText(tr("Not Found! Make sure the documentation path is set in the Configuration Dialog."));
 		return;
 	}
-#ifdef Q_OS_WIN32
-	QStringList searchPaths;
-	searchPaths << docDir;
-	ui->text->setSearchPaths(searchPaths);
-	QTextStream in(&file);
-	in.setAutoDetectUnicode(true);
-	ui->text->setHtml(in.readAll());
-#else
 
-    if(QFileInfo(fileName).suffix() == ".md") {
+//#ifdef Q_OS_WIN32
+//	QStringList searchPaths;
+//	searchPaths << docDir;
+//	ui->text->setSearchPaths(searchPaths);
+//	QTextStream in(&file);
+//	in.setAutoDetectUnicode(true);
+//	ui->text->setHtml(in.readAll());
+//#else
+
+ // seems that setSource work now for Windows too. Needs testing
+    if (QFileInfo(fileName).suffix() == ".md") {
         QFile file(fileName);
         QTextStream md(&file);
+#if QT_VERSION >= 0x051400
         ui->text->document()->setMarkdown(md.readAll());
         ui->text->setHtml(ui->text->document()->toHtml());
+#else
+        ui->text->document()->setPlainText(md.readAll());
+#endif
     }
     else {
         QUrl url = QUrl::fromLocalFile(fileName);
@@ -198,11 +204,12 @@ void DockHelp::loadFile(QString fileName, QString anchor) {
         ui->text->setSource(url);
     }
 
-#endif
+
+//#endif
 
 }
 
-void DockHelp::setTheme(QString theme)
+void DockHelp::setIconTheme(QString theme)
 {
     ui->backButton->setIcon(QIcon(QString(":/themes/%1/browse-prev.png").arg(theme)));
     ui->forwardButton->setIcon(QIcon(QString(":/themes/%1/browse-next.png").arg(theme)));
@@ -268,12 +275,14 @@ void DockHelp::followLink(QUrl url)
 				// This could be fixed using the WebKit rendering engine
 				QMessageBox::warning(this, tr("CsoundQt"),
 									 tr("Frames version only available in external browser."));
+                 emit requestExternalBrowser(url);
 			}
 		}
 	}
 	else {
-		QMessageBox::warning(this, tr("CsoundQt"),
-							 tr("External links can't be followed in help browser."));
+//		QMessageBox::warning(this, tr("CsoundQt"),
+//							 tr("External links can't be followed in help browser."));
+        emit requestExternalBrowser(url); // connected to CsoundQt::openInExternalBrowser
 	}
 }
 
