@@ -43,7 +43,7 @@ public:
     void loadFile(QString fileName, QString anchor="");
 	bool externalBrowser;
 	QString docDir;
-    void setTheme(QString theme);
+    void setIconTheme(QString theme);
 
 private:
 	QTextDocument::FindFlags findFlags;
@@ -86,6 +86,7 @@ private:
 signals:
 	void Close(bool visible);
 	void openManualExample(QString fileName);
+    void requestExternalBrowser(QUrl url);
 
 };
 
