@@ -42,7 +42,8 @@ public:
 	bool insertComplete; // Whether to insert full text or only opcode name
 
 protected:
-	virtual void keyPressEvent(QKeyEvent * event);
+    virtual void keyPressEvent(QKeyEvent * event);
+
 signals:
 	void keyPressed(QString text); // Used to send both pressed keys and full opcode text to be pasted
 };
@@ -68,7 +69,7 @@ public:
 	~DocumentView();
 
 	void insertText(QString text, int section = -1);
-	void setAutoComplete(bool autoComplete);
+    void setAutoComplete(bool autoComplete, int delay = 0);
 	void setAutoParameterMode(bool autoParameterMode);
 	void setViewMode(int mode);
 
@@ -84,9 +85,10 @@ public:
 	int getViewMode();
 
 	QString wordUnderCursor();
+    QString lineUnderCursor();
 	QString getActiveSection();
 	QString getActiveText();
-	int currentLine();
+    int currentLineNumber();
 	bool isModified();
 	bool childHasFocus();
 	void print(QPrinter *printer);
@@ -99,10 +101,11 @@ public:
     Highlighter* getHighlighter() { return &m_highlighter; }
     void gotoLineDialog();
     void markCurrentPosition();
+    const QStringList getAllWords();
 
 
 public slots:
-	void setModified(bool mod = true);
+    void setModified(bool mod = true);
     void syntaxCheck();
 	void textChanged();
 	void escapePressed();
@@ -113,7 +116,7 @@ public slots:
 	void getToIn(); // chnget/chnset to invalue/outvalue
 	void inToGet(); // invalue/outvalue to chnget/chnset
 	void insertAutoCompleteText();
-	void findString(QString query = QString());
+    void findString(QString query = QString());
 	void evaluate();
 	void updateContext();
 	void updateOrcContext(QString orc);
@@ -123,6 +126,7 @@ public slots:
 	void hideHoverText();
 	void updateHoverText(int x, int y, QString text);
 	void createContextMenu(QPoint pos);
+    void autoCompleteAtCursor();
 
 	void showOrc(bool);
 	void showScore(bool);
@@ -171,7 +175,9 @@ private:
 
 	bool m_isModified;
 	bool m_autoComplete;
-	bool m_autoParameterMode;
+    int m_autoCompleteDelay = 150;
+    QTimer* m_autoCompleteTimer = nullptr;
+    bool m_autoParameterMode;
 	bool errorMarked;
 	bool internalChange;  // to let popoup opcode completion know if text change was internal
 	QTextEdit * m_currentEditor;
@@ -181,6 +187,20 @@ private:
 	QString lastReplace;
 	QStringList m_localVariables;
 	QStringList m_globalVariables;
+    QTime m_lastWordsUpdate;
+    QStringList m_allWords;
+    int m_lastCursorPosition;
+    QStringList m_longOptions = {
+        "syntax-check-only", "control-rate=", "messagelevel=",
+        "env:", "dither", "sched", "omacro:", "smacro:",
+        "verbose", "sample-accurate", "realtime",
+        "nchnls=", "nchnls_i=", "sinesize", "daemon",
+        "port=", "use-system-sr", "ksmps=",
+        "limiter", "udp-echo", "opcode-dir="
+    };
+    QStringList m_longOptions2 = {"rtmidi", "rtaudio"};
+
+    // QTime m_lastContextUpdate;
 
     QList<int> cursorPositions;
 
