@@ -41,8 +41,7 @@ QVector<ParenthesisInfo *> TextBlockData::parentheses()
 void TextBlockData::insert(ParenthesisInfo *info)
 {
 	int i = 0;
-	while (i < m_parentheses.size() &&
-		info->position > m_parentheses.at(i)->position)
+    while (i < m_parentheses.size() && info->position > m_parentheses.at(i)->position)
 		++i;
 
 	m_parentheses.insert(i, info);
@@ -60,15 +59,6 @@ void Highlighter::setTheme(const QString &theme) {
     if(theme == "none") {
         defaultFormat.setForeground(QColor("black"));
         defaultFormat.setBackground(QColor(250, 250, 250));
-        /*
-        csdtagFormat = defaultFormat;
-        instFormat = defaultFormat;
-        keywordFormat = defaultFormat;
-        headerFormat = defaultFormat;
-        opcodeFormat = defaultFormat;
-        singleLineCommentFormat  = defaultFormat;
-        */
-
     }
     else if(theme == "classic") {
         defaultFormat.setForeground(QColor("black"));
@@ -311,6 +301,9 @@ void Highlighter::setTheme(const QString &theme) {
     gstringVarFormat.setFontWeight(QFont::Bold);
     gstringVarFormat.setFontItalic(true);
 
+    errorFormat.setForeground(deprecatedFormat.foreground().color());
+    errorFormat.setFontStrikeOut(true);
+
     // ioFormat.setFontItalic(true);
 
     QColor color = saturateColor(headerFormat.foreground().color().lighter(150), 150);
@@ -494,6 +487,8 @@ Highlighter::~Highlighter()
 void Highlighter::setOpcodeNameList(QStringList list)
 {
 	m_opcodeList = list;
+    //QSet<QString>(list.begin(), list.end()); // does not work with older Qt versions
+    m_opcodesSet = list.toSet();
 	//   setFirstRules();
 	setLastRules();
 }
@@ -518,11 +513,13 @@ void Highlighter::highlightBlock(const QString &text)
         return;
 
     // for parenthesis
-    // auto *data = static_cast<TextBlockData*>(currentBlockUserData());
     auto data = static_cast<TextBlockData*>(currentBlockUserData());
     if(data == nullptr) {
         data = new TextBlockData;
     }
+    else {
+        data->clearParenthesis();
+    }
 
     int leftPos = text.indexOf('(');
     while (leftPos != -1) {
@@ -650,11 +647,11 @@ void Highlighter::highlightCsoundBlock(const QString &line)
     // auto text = line.mid(0, commentIndex);
 
     int index = 0;
-    int length;
+    int length = 0;
 
     auto blockdata = static_cast<TextBlockData*>(currentBlockUserData());
 
-    rx.setPattern("^\\s*<\\/?(CsInstruments|CsOptions|CsoundSynthesizer|CsScore|)>");
+    rx.setPattern("^\\s*<\\/?(CsInstruments|CsOptions|CsoundSynthesizer|CsScore|CsFileB|CsLicense|html).*>");
     rxmatch = rx.match(line);
     if(rxmatch.hasMatch()) {
         if(rxmatch.captured(1) == "CsInstruments") {
@@ -685,8 +682,11 @@ void Highlighter::highlightCsoundBlock(const QString &line)
         }
         return;
     }
-    auto text = QStringRef(&line, 0, commentIndex);
+    else if(blockdata->section == UnknownSection) {
+        return;
+    }
 
+    auto text = QStringRef(&line, 0, commentIndex);
 
     // define
     rx.setPattern("^\\s*#define\\s+[_\\w\\ \\t]*#.*#");
@@ -722,6 +722,7 @@ void Highlighter::highlightCsoundBlock(const QString &line)
     }
     */
     QRegularExpression expressionRx("\\b[\\w:]+\\b");
+    QRegularExpression pfieldRx("\\bp[\\d]+\\b");
     index = 0;
     while((rxmatch = expressionRx.match(text, index)).hasMatch()) {
         int wordStart = rxmatch.capturedStart();
@@ -732,8 +733,6 @@ void Highlighter::highlightCsoundBlock(const QString &line)
             auto prev = text.at(wordStart - 1);
             if(prev == '$' || prev == '#') {
                 // check if macro name - replacement for regexp solution
-                wordStart--;
-                length++;
                 setFormat(wordStart-1, wordEnd - wordStart + 1, macroDefineFormat);
                 index = wordEnd;
                 continue;
@@ -741,7 +740,7 @@ void Highlighter::highlightCsoundBlock(const QString &line)
         }
 		wordEnd = (wordEnd > 0 ? wordEnd : text.size());
         QString word = rxmatch.captured();
-        if(word.indexOf(QRegularExpression("p[\\d]+\\b")) != -1) {
+        if(pfieldRx.match(word).hasMatch()) {
 			setFormat(wordStart, wordEnd - wordStart, pfieldFormat);
 		}
         else if(instPatterns.contains(word)) {
@@ -762,13 +761,17 @@ void Highlighter::highlightCsoundBlock(const QString &line)
         else if(ioPatterns.contains(word)) {
             setFormat(wordStart, wordEnd - wordStart, ioFormat);
         }
-        else if(word.contains(":")) {
-			QStringList parts = word.split(":");
+        else if(word[word.size()-1] != ':' && word.contains(":")) {
+            // functional style opcode:k(...)
+            auto parts = word.split(":");
 			if (parts.size() == 2) {
-				if (findOpcode(parts[0]) >= 0) {
+                if (isOpcode(parts[0])) {
 					setFormat(wordStart, wordEnd - wordStart, opcodeFormat);
 				}
 			}
+            else {
+                setFormat(wordStart, wordEnd - wordStart, errorFormat);
+            }
 		}
         else if(m_parsedUDOs.contains(word)) {
             setFormat(wordStart, wordEnd - wordStart, udoFormat);
@@ -776,7 +779,7 @@ void Highlighter::highlightCsoundBlock(const QString &line)
         else if(deprecatedOpcodes.contains(word)) {
             setFormat(wordStart, wordEnd - wordStart, deprecatedFormat);
         }
-        else if(findOpcode(word) >= 0) {
+        else if(isOpcode(word)) {
 			setFormat(wordStart, wordEnd - wordStart, opcodeFormat);
 		}
         else if(colorVariables) {
@@ -1034,6 +1037,11 @@ void Highlighter::setLastRules()
     // lastHighlightingRules.append(rule);
 }
 
+bool Highlighter::isOpcode(QString name) {
+    // Returns true if name is a known opcode
+    return m_opcodesSet.contains(name);
+}
+
 int Highlighter::findOpcode(QString opcodeName, int start, int end)
 {
 	//   fprintf(stderr, "%i - %i\n", start, end);
