@@ -138,6 +138,7 @@ QStringList OpEntryParser::opcodeNameList()
 void OpEntryParser::addOpcode(Opcode opcode)
 {
     opcodeList.append(opcode);
+    opcodeMap.insert(opcode.opcodeName, opcode);
 }
 
 void OpEntryParser::addFlag(QString flag, QString desc) {
@@ -147,12 +148,14 @@ void OpEntryParser::addFlag(QString flag, QString desc) {
     opcodeList.append(opcode);
 }
 
+
+bool OpEntryParser::isKnownOpcode(QString name) {
+    return opcodeMap.contains(name) || m_udosMap->contains(name);
+}
+
 Opcode OpEntryParser::findOpcode(QString opcodeName) {
-    for (int i = 0; i < opcodeList.size(); i++) {
-        if (opcodeList[i].opcodeName == opcodeName) {
-            return opcodeList[i];
-        }
-    }
+    if(opcodeMap.contains(opcodeName))
+        return opcodeMap.value(opcodeName);
     if(m_udosMap->contains(opcodeName)) {
         return m_udosMap->value(opcodeName);
     }
@@ -270,13 +273,13 @@ bool OpEntryParser::getOpcodeArgNames(Node &node)
     if (inArgs.contains("["))
         inArgsOpt = inArgs.mid(inArgs.indexOf("["));
     inArgs.remove(inArgsOpt);
-    QStringList args = inArgs.split(QRegExp("[,\\\"]+"), Qt::SkipEmptyParts);
+    QStringList args = inArgs.split(QRegExp("[,\\\"]+"), SKIP_EMPTY_PARTS);
     for (int count = 0; count < args.size(); count ++) {
         args[count] = args[count].trimmed();
         if (args[count] == "")
             args.removeAt(count);
     }
-    QStringList argsOpt = inArgsOpt.split(QRegExp("[,\\\\\\s\\[\\]]+"), Qt::SkipEmptyParts);
+    QStringList argsOpt = inArgsOpt.split(QRegExp("[,\\\\\\s\\[\\]]+"), SKIP_EMPTY_PARTS);
     for (int j = 0; j < inputs.size(); j++) {
         if (j < args.size()) {
             inputs[j].argName = args[j];
@@ -304,8 +307,8 @@ bool OpEntryParser::getOpcodeArgNames(Node &node)
     if (outArgs.contains("["))
         outArgsOpt = outArgs.mid(outArgs.indexOf("["));
     outArgs.remove(outArgsOpt);
-    args = outArgs.split(QRegExp("[,\\s]+"), Qt::SkipEmptyParts);
-    argsOpt = outArgsOpt.split(QRegExp("[,\\\\\\s\\[\\]]"), Qt::SkipEmptyParts);
+    args = outArgs.split(QRegExp("[,\\s]+"), SKIP_EMPTY_PARTS);
+    argsOpt = outArgsOpt.split(QRegExp("[,\\\\\\s\\[\\]]"), SKIP_EMPTY_PARTS);
     for (int j = 0; j < outputs.size(); j++) {
         if (j < args.size()) {
             outputs[j].argName = args[j];
