@@ -186,6 +186,7 @@ public slots:
 	void evaluateCsound(QString code = QString());
 	void breakpointReached();
     void setParsedUDOs();
+    void openExternalBrowser(QUrl url = QUrl());
 
 
 protected:
@@ -253,7 +254,7 @@ private slots:
 	void virtualCCIn(int channel, int cc, int value);
 	void handleTableSyntax(QString syntax);
 	void openManualExample(QString fileName);
-	void openExternalBrowser(QUrl url = QUrl());
+    //void openExternalBrowser(QUrl url = QUrl()); // moved to public slots to connect with helpPanel
 	void openPdfFile(QString name);
 	void openFLOSSManual();
 	void openQuickRef();
@@ -266,8 +267,8 @@ private slots:
 	void downloadManual();
 	void about();
 	void donate();
-	void documentWasModified();
-	void configure();
+    void documentWasModified(bool status=true);
+    void configure();
 	void applySettings();
 	void setCurrentOptionsForPage(DocumentPage *p);
 	void runUtility(QString flags);
@@ -295,6 +296,7 @@ private slots:
     void testAudioSetup();
     void checkSyntaxMenuAction();
     void tabMoved(int to, int from);
+    void openExamplesFolder();
 
     DocumentPage *getCurrentDocumentPage() {
         if(curPage >= documentPages.size())
@@ -335,6 +337,7 @@ private:
 	void clearSettings();
     void setToolbarIconSize(int size);
     int execute(QString executable, QString options);
+    int startProcess(QString executable, const QStringList &args);
     //    bool saveCurrent();
 	bool makeNewPage(QString fileName, QString text);
 	bool loadCompanionFile(const QString &fileName);
@@ -351,7 +354,9 @@ private:
 	void openLogFile();
 	void showNewFormatWarning();
 	void setupEnvironment();
-	ConfigLists m_configlists;
+    void openHtmlHelp(QString fileName, QString entry, bool external);
+
+    ConfigLists m_configlists;
 	QTabWidget *documentTabs;
 	GraphicWindow *m_graphic;  // To display the code graph images
 	QVector<DocumentPage *> documentPages;
@@ -507,6 +512,7 @@ private:
     QAction *lineNumbersAct;
 	QAction *parameterModeAct;
 //	QAction *showParametersAct;
+    QAction *openExamplesFolderAct;
     QSignalMapper *focusMapper;
 	int curPage;
 	int curCsdPage;  // To recall last csd visited
@@ -534,6 +540,15 @@ private:
     QString m_fullScreenComponent;
     QDir m_rissetDataPath;
     bool isDarkPalette;
+    QStringList m_longOptions = {
+        "--syntax-check-only", "--control-rate=", "--messagelevel=",
+        "--env:", "--dither", "--sched", "--omacro:", "--smacro:",
+        "--verbose", "--sample-accurate", "--realtime",
+        "--nchnls=", "--nchnls_i=", "--sinesize", "--daemon",
+        "--port=", "--use-system-sr", "--ksmps=",
+        "--limiter", "--udp-echo", "--opcode-dir=", "-+rtmidi", "-+rtaudio",
+        "--format"
+    };
 };
 
 class FileOpenEater : public QObject
@@ -545,7 +560,7 @@ public:
 		m_mw = mainWindow;
 		while (!fileEventQueue.isEmpty()) {
 			QString fileName = fileEventQueue.takeFirst();
-            qDebug() << "FileOpenEater::setMainWindow  opening file" << fileName << Qt::endl;
+            qDebug() << "FileOpenEater::setMainWindow  opening file" << fileName << ENDL; // use macro for Qt version compatibility
 			m_mw->loadFileFromSystem(fileName);
 		}
 	}
