@@ -23,6 +23,8 @@
 #include "qutetext.h"
 #include <math.h>
 
+#define USEFONTPIXELSIZE
+
 QuteText::QuteText(QWidget *parent) : QuteWidget(parent)
 {
 	m_value = 0.0;
@@ -34,7 +36,7 @@ QuteText::QuteText(QWidget *parent) : QuteWidget(parent)
     // Necessary to pass mouse tracking to widget panel for _MouseX channels
     m_widget->setMouseTracking(true);
     setMouseTracking(true);
-    // m_widget->setAttribute(Qt::WA_TransparentForMouseEvents, true);
+
     //  canFocus(true);
 
 	//   connect(static_cast<QLabel*>(m_widget), SIGNAL(popUpMenu(QPoint)), this, SLOT(popUpMenu(QPoint)));
@@ -94,6 +96,12 @@ void QuteText::setType(QString type)
 	m_type = type;
 }
 
+void QuteText::setTransparentForMouse(bool status)
+{
+    m_widget->setAttribute(Qt::WA_TransparentForMouseEvents, status);
+    setAttribute(Qt::WA_TransparentForMouseEvents, status);
+}
+
 void QuteText::setAlignment(QString alignment)
 {
     Qt::Alignment align;
@@ -224,16 +232,18 @@ void QuteText::applyInternalProperties()
     }
     QString borderStyle = borderWidth > 0 ? "solid" : "none";
 
-	int new_fontSize = 0;
-	int totalHeight = 0;
-	double fontSize = (property("QCS_fontsize").toDouble()*m_fontScaling) + m_fontOffset;
+    double scaledFontSize = property("QCS_fontsize").toDouble() * m_fontScaling;
+    double fontSize = scaledFontSize + m_fontOffset;
 
+    /*
 	while (totalHeight < fontSize + 1) {
-		new_fontSize++;
-		QFont font(property("QCS_font").toString(), new_fontSize);
+        new_fontSize += 2;
+        font.setPointSize(new_fontSize);
+        // QFont font(property("QCS_font").toString(), new_fontSize);
 		QFontMetricsF fm(font);
-		totalHeight = fm.ascent() + fm.descent();
+        totalHeight = fm.ascent() + fm.descent();
 	}
+    */
 
     QString bgstr = property("QCS_bgcolormode").toBool() ?
         (QString("; background-color:")+property("QCS_bgcolor").value<QColor>().name()) :
@@ -241,7 +251,8 @@ void QuteText::applyInternalProperties()
 
     m_widget->setStyleSheet(
         "QLabel{ font-family:\"" + property("QCS_font").toString() + "\""
-            + "; font-size: " + QString::number(new_fontSize) + "pt"
+            // + "; font-size: " + QString::number(new_fontSize) + "pt"
+            + "; font-size: " + QString::number(fontSize) + "px"
             + bgstr
             + "; color:" + property("QCS_color").value<QColor>().name()
             + "; border-color:" + property("QCS_color").value<QColor>().name()
@@ -701,6 +712,14 @@ QuteLineEdit::QuteLineEdit(QWidget* parent) : QuteText(parent)
 	setProperty("QCS_bordermode", QVariant()); // Remove these property
 	setProperty("QCS_borderradius", QVariant()); // Remove these property
 	setProperty("QCS_borderwidth", QVariant()); // Remove these property
+
+    // Necessary to pass mouse tracking to widget panel for _MouseX channels
+    m_widget->setMouseTracking(true);
+    setMouseTracking(true);
+
+    m_widget->setAttribute(Qt::WA_TransparentForMouseEvents, false);
+    setAttribute(Qt::WA_TransparentForMouseEvents, false);
+
 }
 
 QuteLineEdit::~QuteLineEdit()
@@ -846,6 +865,18 @@ void QuteLineEdit::applyInternalProperties()
 	int totalHeight = 0;
 	double fontSize = (property("QCS_fontsize").toDouble()*m_fontScaling) + m_fontOffset;
 
+#ifdef USEFONTPIXELSIZE
+    m_widget->setStyleSheet("QLineEdit { font-family:\"" + property("QCS_font").toString()
+                            + "\"; font-size: " + QString::number(fontSize) + "px"
+                            + (property("QCS_bgcolormode").toBool() ?
+                                   QString("; background-color:") + property("QCS_bgcolor").value<QColor>().name() : QString("; "))
+                            + "; color:" + property("QCS_color").value<QColor>().name()
+                            + "; border-color:" + property("QCS_color").value<QColor>().name()
+                            + "; border-radius:" + QString::number(property("QCS_borderradius").toInt()) + "px"
+                            + "; border-width:" + QString::number(property("QCS_borderwidth").toInt()) + "px"
+                            + "; border-style: " + borderStyle
+                            + "; }");
+#else
 	while (totalHeight < fontSize + 1) {
 		new_fontSize++;
 		QFont font(property("QCS_font").toString(), new_fontSize);
@@ -863,6 +894,7 @@ void QuteLineEdit::applyInternalProperties()
 							+ "; border-width:" + QString::number(property("QCS_borderwidth").toInt()) + "px"
 							+ "; border-style: " + borderStyle
 							+ "; }");
+#endif
 	//  qDebug() << "QuteLineEdit::applyInternalProperties() sylesheet" <<  m_widget->styleSheet();
 }
 
